summaryrefslogtreecommitdiff
path: root/test/motion_sense.c
diff options
context:
space:
mode:
Diffstat (limited to 'test/motion_sense.c')
-rw-r--r--test/motion_sense.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/test/motion_sense.c b/test/motion_sense.c
index 1a5d808044..c332f962c5 100644
--- a/test/motion_sense.c
+++ b/test/motion_sense.c
@@ -70,15 +70,15 @@ static int test_lid_angle(void)
TEST_ASSERT(motion_get_lid_angle() == -135);
/*
* Align base with hinge and make sure it returns 0 for angle. In this
* test it doesn't matter what the lid acceleration vector is.
*/
mock_x_acc[ACCEL_BASE] = 0;
mock_y_acc[ACCEL_BASE] = 1000;
mock_z_acc[ACCEL_BASE] = 0;
task_wake(TASK_ID_MOTIONSENSE);
msleep(5);
- TEST_ASSERT(motion_get_lid_angle() == 0);
+ TEST_ASSERT(motion_get_lid_angle() == LID_ANGLE_UNRELIABLE);
/*
* Use all three axes and set lid to negative base and make sure
@@ -70,15 +70,15 @@ static int test_lid_angle(void)
TEST_ASSERT(motion_get_lid_angle() == -135);
/*
- * Align base with hinge and make sure it returns 0 for angle. In this
- * test it doesn't matter what the lid acceleration vector is.
+ * Align base with hinge and make sure it returns unreliable for angle.
+ * In this test it doesn't matter what the lid acceleration vector is.
*/
mock_x_acc[ACCEL_BASE] = 0;